/* This file was generated by syncqt. */
#ifndef QT_QTLOCATION_VERSION_H
#define QT_QTLOCATION_VERSION_H

#define QTLOCATION_VERSION_STR "6.6.2"

#define QTLOCATION_VERSION 0x060602

#endif // QT_QTLOCATION_VERSION_H
